#include "obgtkTearoffMenuItem.h"

@implementation Gtk_TearoffMenuItem
- castGtkTearoffMenuItem:(GtkTearoffMenuItem *) castitem
{
  gtktearoffmenuitem = castitem;

  return [self castGtkMenuItem:GTK_MENU_ITEM(castitem)];
}

- init
{
  return [self castGtkTearoffMenuItem:GTK_TEAROFF_MENU_ITEM(gtk_tearoff_menu_item_new())];
}

@end
